@@ -37,6 +37,7 @@
 #include "rocauxiliary_sterf.hpp"
 #include "rocblas.hpp"
 #include "rocsolver/rocsolver.h"
+#include "rocsolver_run_specialized_kernels.hpp"
 
 #include <algorithm>
 
@@ -2059,9 +2060,9 @@ void local_gemm(rocblas_handle handle,
     S zero = 0.0;
 
     // temp = A*B
-    rocblasCall_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, A,
-                     shiftA, lda, strideA, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt,
-                     strideT, batch_count, workArr);
+    rocsolver_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, A, shiftA,
+                   lda, strideA, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt, strideT,
+                   batch_count, workArr);
 
     // A = temp
     hipStream_t stream;
@@ -2112,9 +2113,9 @@ void local_gemm(rocblas_handle handle,
                             strideA, work, rocblas_fill_full);
 
     // temp = work*B
-    rocblasCall_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, work,
-                     shiftT, ldt, strideT, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt,
-                     strideT, batch_count, workArr);
+    rocsolver_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, work,
+                   shiftT, ldt, strideT, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt, strideT,
+                   batch_count, workArr);
 
     // real(A) = temp
     ROCSOLVER_LAUNCH_KERNEL((copy_mat<T, S, true>), dim3(blocks, blocks, batch_count),
@@ -2127,9 +2128,9 @@ void local_gemm(rocblas_handle handle,
                             strideA, work, rocblas_fill_full);
 
     // temp = work*B
-    rocblasCall_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, work,
-                     shiftT, ldt, strideT, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt,
-                     strideT, batch_count, workArr);
+    rocsolver_gemm(handle, rocblas_operation_none, rocblas_operation_none, n, n, n, &one, work,
+                   shiftT, ldt, strideT, B, shiftT, ldt, strideT, &zero, temp, shiftT, ldt, strideT,
+                   batch_count, workArr);
 
     // imag(A) = temp
     ROCSOLVER_LAUNCH_KERNEL((copy_mat<T, S, false>), dim3(blocks, blocks, batch_count),
