@@ -65,6 +65,9 @@ rocblas_status larfg_run_small(rocblas_handle handle,
                                U alpha,
                                const rocblas_stride shiftA,
                                const rocblas_stride strideA,
+                               T* beta,
+                               const rocblas_stride shiftB,
+                               const rocblas_stride strideB,
                                U x,
                                const rocblas_stride shiftX,
                                const I incX,
@@ -184,7 +187,7 @@ rocblas_status rocsolver_trsm_upper(rocblas_handle handle,
                                     void* work4);
 
 // gemm
-template <bool BATCHED, bool STRIDED, typename T, typename I, typename U>
+template <typename T, typename I, typename U1, typename U2, typename U3>
 rocblas_status rocsolver_gemm(rocblas_handle handle,
                               rocblas_operation transA,
                               rocblas_operation transB,
@@ -192,23 +195,23 @@ rocblas_status rocsolver_gemm(rocblas_handle handle,
                               I n,
                               I k,
                               const T* alpha,
-                              U A,
+                              U1 A,
                               rocblas_stride shiftA,
                               I lda,
                               rocblas_stride strideA,
-                              U B,
+                              U2 B,
                               rocblas_stride shiftB,
                               I ldb,
                               rocblas_stride strideB,
                               const T* beta,
-                              U C,
+                              U3 C,
                               rocblas_stride shiftC,
                               I ldc,
                               rocblas_stride strideC,
                               I batch_count,
                               T** work);
 
-template <bool BATCHED, bool STRIDED, typename T, typename I, typename U>
+template <typename T, typename I, typename U1, typename U2, typename U3>
 rocblas_status rocsolver_gemm(rocblas_handle handle,
                               rocblas_operation transA,
                               rocblas_operation transB,
@@ -216,18 +219,18 @@ rocblas_status rocsolver_gemm(rocblas_handle handle,
                               I n,
                               I k,
                               const T* alpha,
-                              U A,
+                              U1 A,
                               rocblas_stride shiftA,
                               I inca,
                               I lda,
                               rocblas_stride strideA,
-                              U B,
+                              U2 B,
                               rocblas_stride shiftB,
                               I incb,
                               I ldb,
                               rocblas_stride strideB,
                               const T* beta,
-                              U C,
+                              U3 C,
                               rocblas_stride shiftC,
                               I incc,
                               I ldc,
