@@ -69,7 +69,7 @@ void rocsolver_geqr2_getMemorySize(const I m,
     *size_Abyx_norms = std::max(s1, s2);
 
     // size of array to store temporary diagonal values
-    *size_diag = sizeof(T) * batch_count;
+    *size_diag = sizeof(T) * std::min(m, n) * batch_count;
 }
 
 template <typename T, typename I, typename U>
@@ -131,18 +131,13 @@ rocblas_status rocsolver_geqr2_template(rocblas_handle handle,
     for(I j = 0; j < dim; ++j)
     {
         // generate Householder reflector to work on column j
-        rocsolver_larfg_template(handle, m - j, A, shiftA + idx2D(j, j, lda), A,
-                                 shiftA + idx2D(std::min(j + 1, m - 1), j, lda), (I)1, strideA,
-                                 (ipiv + j), strideP, batch_count, (T*)work_workArr, Abyx_norms);
+        rocsolver_larfg_template<T>(handle, m - j, A, shiftA + idx2D(j, j, lda), diag, j, dim, A,
+                                    shiftA + idx2D(std::min(j + 1, m - 1), j, lda), (I)1, strideA,
+                                    (ipiv + j), strideP, batch_count, (T*)work_workArr, Abyx_norms);
 
         // Apply Householder reflector to the rest of matrix from the left
         if(j < n - 1)
         {
-            // insert one in A(j,j) tobuild/apply the householder matrix
-            ROCSOLVER_LAUNCH_KERNEL((set_diag<T, I>), dim3(batch_count, 1, 1), dim3(1, 1, 1), 0,
-                                    stream, diag, 0, 1, A, shiftA + idx2D(j, j, lda), lda, strideA,
-                                    (I)1, true);
-
             // conjugate tau
             if(COMPLEX)
                 rocsolver_lacgv_template<T>(handle, (I)1, ipiv, j, (I)1, strideP, batch_count);
@@ -152,17 +147,19 @@ rocblas_status rocsolver_geqr2_template(rocblas_handle handle,
                                     A, shiftA + idx2D(j, j + 1, lda), lda, strideA, batch_count,
                                     scalars, Abyx_norms, (T**)work_workArr);
 
-            // restore original value of A(j,j)
-            ROCSOLVER_LAUNCH_KERNEL((restore_diag<T, I>), dim3(batch_count, 1, 1), dim3(1, 1, 1), 0,
-                                    stream, diag, 0, 1, A, shiftA + idx2D(j, j, lda), lda, strideA,
-                                    (I)1);
-
             // restore tau
             if(COMPLEX)
                 rocsolver_lacgv_template<T>(handle, (I)1, ipiv, j, (I)1, strideP, batch_count);
         }
     }
 
+    // restore diagonal values of A
+    constexpr int DIAG_NTHREADS = 64;
+    I blocks = (dim - 1) / DIAG_NTHREADS + 1;
+    ROCSOLVER_LAUNCH_KERNEL((restore_diag<T, I>), dim3(batch_count, blocks, 1),
+                            dim3(1, DIAG_NTHREADS, 1), 0, stream, diag, 0, dim, A, shiftA, lda,
+                            strideA, dim);
+
     return rocblas_status_success;
 }
 
