@@ -39,6 +39,7 @@
 #include "roclapack_geqrf.hpp"
 #include "roclapack_syevj_heevj.hpp"
 #include "rocsolver/rocsolver.h"
+#include "rocsolver_run_specialized_kernels.hpp"
 
 ROCSOLVER_BEGIN_NAMESPACE
 
@@ -316,9 +317,9 @@ rocblas_status rocsolver_gesvdj_template(rocblas_handle handle,
         rocblas_int ldv_gemm = n;
         rocblas_int strideV_gemm = n * n;
 
-        rocblasCall_gemm(handle, rocblas_operation_conjugate_transpose, rocblas_operation_none, n,
-                         n, m, &minone, A, shiftA, lda, strideA, A, shiftA, lda, strideA, &zero,
-                         V_gemm, 0, ldv_gemm, strideV_gemm, batch_count, (T**)work6_workArr);
+        rocsolver_gemm(handle, rocblas_operation_conjugate_transpose, rocblas_operation_none, n, n,
+                       m, &minone, A, shiftA, lda, strideA, A, shiftA, lda, strideA, &zero, V_gemm,
+                       0, ldv_gemm, strideV_gemm, batch_count, (T**)work6_workArr);
 
         // apply eigenvalue decomposition to -A'A, obtaining V as eigenvectors
         rocsolver_syevj_heevj_template<false, STRIDED, T>(
@@ -332,9 +333,9 @@ rocblas_status rocsolver_gesvdj_template(rocblas_handle handle,
         rocblas_int ldu_gemm = (leftv ? ldu : m);
         rocblas_int strideU_gemm = (leftv ? strideU : m * n);
 
-        rocblasCall_gemm(handle, rocblas_operation_none, rocblas_operation_none, m, n, n, &one, A,
-                         shiftA, lda, strideA, V_gemm, 0, ldv_gemm, strideV_gemm, &zero, U_gemm, 0,
-                         ldu_gemm, strideU_gemm, batch_count, (T**)work6_workArr);
+        rocsolver_gemm(handle, rocblas_operation_none, rocblas_operation_none, m, n, n, &one, A,
+                       shiftA, lda, strideA, V_gemm, 0, ldv_gemm, strideV_gemm, &zero, U_gemm, 0,
+                       ldu_gemm, strideU_gemm, batch_count, (T**)work6_workArr);
 
         // apply QR factorization to AV, obtaining U = Q and S = R
         rocsolver_geqrf_template<false, STRIDED, T>(handle, m, n, U_gemm, 0, ldu_gemm, strideU_gemm,
@@ -368,9 +369,9 @@ rocblas_status rocsolver_gesvdj_template(rocblas_handle handle,
         rocblas_int ldu_gemm = (leftv ? ldu : m);
         rocblas_int strideU_gemm = (leftv ? strideU : m * m);
 
-        rocblasCall_gemm(handle, rocblas_operation_none, rocblas_operation_conjugate_transpose, m,
-                         m, n, &minone, A, shiftA, lda, strideA, A, shiftA, lda, strideA, &zero,
-                         U_gemm, 0, ldu_gemm, strideU_gemm, batch_count, (T**)work6_workArr);
+        rocsolver_gemm(handle, rocblas_operation_none, rocblas_operation_conjugate_transpose, m, m,
+                       n, &minone, A, shiftA, lda, strideA, A, shiftA, lda, strideA, &zero, U_gemm,
+                       0, ldu_gemm, strideU_gemm, batch_count, (T**)work6_workArr);
 
         // apply eigenvalue decomposition to -AA', obtaining U as eigenvectors
         rocsolver_syevj_heevj_template<false, STRIDED, T>(
@@ -384,9 +385,9 @@ rocblas_status rocsolver_gesvdj_template(rocblas_handle handle,
         rocblas_int ldv_gemm = (rightv ? ldv : m);
         rocblas_int strideV_gemm = (rightv ? strideV : m * n);
 
-        rocblasCall_gemm(handle, rocblas_operation_conjugate_transpose, rocblas_operation_none, m,
-                         n, m, &one, U_gemm, 0, ldu_gemm, strideU_gemm, A, shiftA, lda, strideA,
-                         &zero, V_gemm, 0, ldv_gemm, strideV_gemm, batch_count, (T**)work6_workArr);
+        rocsolver_gemm(handle, rocblas_operation_conjugate_transpose, rocblas_operation_none, m, n,
+                       m, &one, U_gemm, 0, ldu_gemm, strideU_gemm, A, shiftA, lda, strideA, &zero,
+                       V_gemm, 0, ldv_gemm, strideV_gemm, batch_count, (T**)work6_workArr);
 
         // apply LQ factorization to U'A, obtaining S = L and V' = Q
         rocsolver_gelqf_template<false, STRIDED, T>(handle, m, n, V_gemm, 0, ldv_gemm, strideV_gemm,
