@@ -1,5 +1,5 @@
 /* **************************************************************************
- * Copyright (C) 2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2023-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -34,6 +34,8 @@
 
 #include "refact_helpers.hpp"
 
+ROCSOLVER_BEGIN_NAMESPACE
+
 // -------------------------------------------
 // Compute B = beta * B + alpha * (P * A * Q') as
 // (1) B = beta * B
@@ -203,3 +205,5 @@ rocblas_status rocsolver_csrrf_refactlu_template(rocblas_handle handle,
 
     return rocblas_status_success;
 }
+
+ROCSOLVER_END_NAMESPACE
